@@ -6,6 +6,7 @@
 
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
+#include <pyorbit.h>
 #include <libnautilus/nautilus-view.h>
 
 void pynautilus_register_classes(PyObject *d);
@@ -18,6 +19,7 @@ initnautilus(void)
     PyObject *m, *d;
 	
     init_pygobject();
+    init_pyorbit();
 
     m = Py_InitModule("nautilus", pynautilus_functions);
     d = PyModule_GetDict(m);
